==> cloudt-context-0.1.8-20220420.090957-1-sources.jar: com/elitesland/cloudt/context/SpringContextHolder.java <==
package com.elitesland.cloudt.context;

import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.ObjectProvider;
import org.springframework.context.ApplicationContext;
import org.springframework.core.env.Environment;
import org.springframework.util.Assert;
import org.springframework.util.StringUtils;

import java.util.Map;

/**
 * Spring Context工具类.
 *
 * @author Kaiser（wang shao）
 * @date 2022/2/18
 */
@Log4j2
public class SpringContextHolder {

    private static ApplicationContext applicationContext;

    private SpringContextHolder() {
    }

    /**
     * 从spring context获取bean
     *
     * @param clazz bean class
     * @param <T>   bean类型
     * @return bean
     */
    public static <T> T getBean(Class<T> clazz) {
        assertContextInjected();
        Assert.notNull(clazz, "bean类型为空");

        return applicationContext.getBean(clazz);
    }

    /**
     * 从spring context获取bean
     *
     * @param name bean名称
     * @return bean
     */
    public static Object getBean(String name) {
        assertContextInjected();
        Assert.hasText(name, "bean名称为空");

        return applicationContext.getBean(name);
    }

    /**
     * 从spring context获取bean
     *
     * @param name  bean名称
     * @param clazz bean class
     * @param <T>   bean类型
     * @return bean
     */
    public static <T> T getBean(String name, Class<T> clazz) {
        assertContextInjected();
        Assert.hasText(name, "bean名称为空");
        Assert.notNull(clazz, "bean类型为空");

        return applicationContext.getBean(name, clazz);
    }

    /**
     * 从spring context获取bean
     *
     * @param clazz bean class
     * @param <T>   bean类型
     * @return bean名称与bean
     */
    public static <T> Map<String, T> getBeans(Class<T> clazz) {
        assertContextInjected();
        Assert.notNull(clazz, "bean类型为空");

        return applicationContext.getBeansOfType(clazz);
    }

    /**
     * 获取beanProvider
     *
     * @param clazz bean
     * @param <T>   bean类型
     * @return beanProvider
     */
    public static <T> ObjectProvider<T> getObjectProvider(Class<T> clazz) {
        assertContextInjected();
        Assert.notNull(clazz, "bean类型为空");

        return applicationContext.getBeanProvider(clazz);
    }

    /**
     * 获取配置
     *
     * @param key key
     * @return 值
     */
    public static String getProperty(String key) {
        return getProperty(key, String.class, null);
    }

    /**
     * 获取配置
     *
     * @param key          key
     * @param defaultValue 默认值
     * @return 值
     */
    public static String getProperty(String key, String defaultValue) {
        return getProperty(key, String.class, defaultValue);
    }

    /**
     * 获取配置
     *
     * @param key       key
     * @param valueType value类型
     * @param <T>       值类型
     * @return 值
     */
    public static <T> T getProperty(String key, Class<T> valueType) {
        return getProperty(key, valueType, null);
    }

    /**
     * 获取配置
     *
     * @param key          key
     * @param valueType    value类型
     * @param defaultValue 默认值
     * @param <T>          值类型
     * @return 值
     */
    public static <T> T getProperty(String key, Class<T> valueType, T defaultValue) {
        Assert.hasText(key, "key为空");
        Assert.notNull(valueType, "值类型为空");

        Environment environment = getBean(Environment.class);
        T value = environment.getProperty(key, valueType);
        if (defaultValue == null) {
            return value;
        }

        if (value == null) {
            return defaultValue;
        }
        if (value instanceof String && !StringUtils.hasText((String) value)) {
            return defaultValue;
        }
        return value;
    }

    /**
     * 装配bean的依赖
     * <p>
     * 支持spring的相关依赖注入，包含Autowired、Resource、Inject等注解
     *
     * @param bean bean
     */
    public static void autowireBean(Object bean) {
        Assert.notNull(bean, "对象为空");
        assertContextInjected();

        applicationContext.getAutowireCapableBeanFactory().autowireBean(bean);
    }

    static void setApplicationContext(ApplicationContext applicationContext) {
        SpringContextHolder.applicationContext = applicationContext;
    }

    private static void assertContextInjected() {
        if (applicationContext == null) {
            throw new IllegalStateException("请先设置applicationContext.");
        }
    }
}

==> cloudt-context-2.0.3-20220309.015805-1-sources.jar: com/elitesland/cloudt/context/SpringContextHolder.java <==
package com.elitesland.cloudt.context;

import lombok.extern.slf4j.Slf4j;
import org.springframework.context.ApplicationContext;
import org.springframework.core.env.Environment;
import org.springframework.util.Assert;
import org.springframework.util.StringUtils;

import java.util.Map;

/**
 * Spring Context工具类.
 *
 * @author Kaiser（wang shao）
 * @date 2022/2/18
 */
@Slf4j
public class SpringContextHolder {

    private static ApplicationContext applicationContext;

    private SpringContextHolder() {
    }

    /**
     * 从spring context获取bean
     *
     * @param clazz bean class
     * @param <T>   bean类型
     * @return bean
     */
    public static <T> T getBean(Class<T> clazz) {
        assertContextInjected();
        Assert.notNull(clazz, "bean类型为空");

        return applicationContext.getBean(clazz);
    }

    /**
     * 从spring context获取bean
     *
     * @param name bean名称
     * @return bean
     */
    public static Object getBean(String name) {
        assertContextInjected();
        Assert.hasText(name, "bean名称为空");

        return applicationContext.getBean(name);
    }

    /**
     * 从spring context获取bean
     *
     * @param name  bean名称
     * @param clazz bean class
     * @param <T>   bean类型
     * @return bean
     */
    public static <T> T getBean(String name, Class<T> clazz) {
        assertContextInjected();
        Assert.hasText(name, "bean名称为空");
        Assert.notNull(clazz, "bean类型为空");

        return applicationContext.getBean(name, clazz);
    }

    /**
     * 从spring context获取bean
     *
     * @param clazz bean class
     * @param <T>   bean类型
     * @return bean名称与bean
     */
    public static <T> Map<String, T> getBeans(Class<T> clazz) {
        assertContextInjected();
        Assert.notNull(clazz, "bean类型为空");

        return applicationContext.getBeansOfType(clazz);
    }

    /**
     * 获取配置
     *
     * @param key key
     * @return 值
     */
    public static String getProperty(String key) {
        return getProperty(key, String.class, null);
    }

    /**
     * 获取配置
     *
     * @param key          key
     * @param defaultValue 默认值
     * @return 值
     */
    public static String getProperty(String key, String defaultValue) {
        return getProperty(key, String.class, defaultValue);
    }

    /**
     * 获取配置
     *
     * @param key       key
     * @param valueType value类型
     * @param <T>       值类型
     * @return 值
     */
    public static <T> T getProperty(String key, Class<T> valueType) {
        return getProperty(key, valueType, null);
    }

    /**
     * 获取配置
     *
     * @param key          key
     * @param valueType    value类型
     * @param defaultValue 默认值
     * @param <T>          值类型
     * @return 值
     */
    public static <T> T getProperty(String key, Class<T> valueType, T defaultValue) {
        Assert.hasText(key, "key为空");
        Assert.notNull(valueType, "值类型为空");

        Environment environment = getBean(Environment.class);
        T value = environment.getProperty(key, valueType);
        if (defaultValue == null) {
            return value;
        }

        if (value == null) {
            return defaultValue;
        }
        if (value instanceof String && !StringUtils.hasText((String) value)) {
            return defaultValue;
        }
        return value;
    }

    /**
     * 装配bean的依赖
     * <p>
     * 支持spring的相关依赖注入，包含Autowired、Resource、Inject等注解
     *
     * @param bean bean
     */
    public static void autowireBean(Object bean) {
        Assert.notNull(bean, "对象为空");
        assertContextInjected();

        applicationContext.getAutowireCapableBeanFactory().autowireBean(bean);
    }

    static void setApplicationContext(ApplicationContext applicationContext) {
        SpringContextHolder.applicationContext = applicationContext;
    }

    private static void assertContextInjected() {
        if (applicationContext == null) {
            throw new IllegalStateException("请先设置applicationContext.");
        }
    }
}
